==> 0.1.2-prerelease.tar.gz: lib/src/core/functions/menus/showModernFormFilterPopupMenu.dart <==
part of modern_form_core;

Future<T> showModernFormFilterPopupMenu<T>(
  BuildContext context, {
  @required List<ModernFormBottomSheetModel<T>> list,
  String title,
  menu.ModernFormPopupMenuLocation menuLocation,
  bool forceMenu,
}) async {
  if (forceMenu == null) {
    forceMenu = list.length > 5;
  }
  Size size = MediaQuery.of(context).size;
  if (size.width > ModernFormUtils.webBreakdown || forceMenu) {
    List<menu.PopupMenuEntry<T>> items = [];

    list.forEach((element) {
      items.add(menu.PopupMenuItem(
        value: element.value,
        child: _Iten(
          title: element.text,
          textColor: element.textColor,
        ),
      ));
    });

    if (items != null && items.isNotEmpty) {
      return await menu.showMenu<T>(
        context: context,
        position: menu.modernFormPopupMenuPosition(context, menuLocation),
        items: items,
        maxHeight: size.width > ModernFormUtils.webBreakdown
            ? size.height * .5
            : size.height * .3,
      );
    } else {
      return null;
    }
  }

  return await showModalBottomSheet(
    isScrollControlled: true,
    context: context,
    builder: (context) {
      return ConstrainedBox(
        constraints: BoxConstraints(maxHeight: ScreenUtil().screenHeight * .6),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ModernFormBottonSheetLabel(label: title ?? ""),
            Expanded(
              child: ListView.builder(
                  padding: EdgeInsets.only(
                      bottom: ScreenUtil().setHeight(15),
                      top: ScreenUtil().setHeight(7)),
                  itemCount: list.length,
                  itemBuilder: (context, index) {
                    ModernFormBottomSheetModel iten = list[index];
                    return _Iten(
                      title: iten.text,
                      textColor: iten.textColor,
                      onTap: () {
                        Navigator.pop(context, iten.value);
                      },
                    );
                  }),
            ),
          ],
        ),
      );
    },
  );
}

class _Iten extends StatelessWidget {
  final String title;
  final Color textColor;
  final Function() onTap;

  const _Iten({Key key, this.title, this.onTap, this.textColor})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.only(
            bottom: ScreenUtil().setSp(15), left: ScreenUtil().setSp(10)),
        child: InkWell(
          onTap: onTap,
          borderRadius: BorderRadius.circular(2),
          child: Padding(
            padding: EdgeInsets.symmetric(vertical: ScreenUtil().setSp(5)),
            child: Wrap(
              crossAxisAlignment: WrapCrossAlignment.start,
              children: [
                Text(
                  title ?? "",
                  style: TextStyle(
                    fontSize: ScreenUtil().setSp(
                        ScreenUtil().screenWidth > ModernFormUtils.webBreakdown
                            ? 16
                            : 18),
                    color: textColor,
                  ),
                ),
              ],
            ),
          ),
        ));
  }
}

==> 0.1.29-prerelease.tar.gz: lib/src/core/functions/menus/showModernFormFilterPopupMenu.dart <==
part of modern_form_core;

Future<T> showModernFormFilterPopupMenu<T>(
  BuildContext context, {
  @required List<ModernFormBottomSheetModel<T>> list,
  String title,
  menu.ModernFormPopupMenuLocation menuLocation,
  bool forceMenu,
}) async {
  if (forceMenu == null) {
    forceMenu = list.length <= 5;
  }
  Size size = MediaQuery.of(context).size;
  if (size.width > ModernFormUtils.webBreakdown || forceMenu) {
    List<menu.PopupMenuEntry<T>> items = [];

    list.forEach((element) {
      items.add(menu.PopupMenuItem(
        value: element.value,
        child: _Iten(
          title: element.text,
          textColor: element.textColor,
        ),
      ));
    });

    if (items != null && items.isNotEmpty) {
      return await menu.showMenu<T>(
        context: context,
        position: menu.modernFormPopupMenuPosition(context, menuLocation),
        items: items,
        maxHeight: size.width > ModernFormUtils.webBreakdown
            ? size.height * .5
            : size.height * .3,
      );
    } else {
      return null;
    }
  }

  return await showModalBottomSheet(
    isScrollControlled: true,
    context: context,
    builder: (context) {
      return ConstrainedBox(
        constraints: BoxConstraints(maxHeight: ScreenUtil().screenHeight * .6),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            ModernFormBottonSheetLabel(label: title ?? ""),
            Expanded(
              child: ListView.builder(
                  padding: EdgeInsets.only(
                      bottom: ScreenUtil().setHeight(15),
                      top: ScreenUtil().setHeight(7)),
                  itemCount: list.length,
                  itemBuilder: (context, index) {
                    ModernFormBottomSheetModel iten = list[index];
                    return _Iten(
                      title: iten.text,
                      textColor: iten.textColor,
                      onTap: () {
                        Navigator.pop(context, iten.value);
                      },
                    );
                  }),
            ),
          ],
        ),
      );
    },
  );
}

class _Iten extends StatelessWidget {
  final String title;
  final Color textColor;
  final Function() onTap;

  const _Iten({Key key, this.title, this.onTap, this.textColor})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: EdgeInsets.only(
            bottom: ScreenUtil().setSp(15), left: ScreenUtil().setSp(10)),
        child: InkWell(
          onTap: onTap,
          borderRadius: BorderRadius.circular(2),
          child: Padding(
            padding: EdgeInsets.symmetric(vertical: ScreenUtil().setSp(5)),
            child: Wrap(
              crossAxisAlignment: WrapCrossAlignment.start,
              children: [
                Text(
                  title ?? "",
                  style: TextStyle(
                    fontSize: ScreenUtil().setSp(
                        ScreenUtil().screenWidth > ModernFormUtils.webBreakdown
                            ? 16
                            : 18),
                    color: textColor,
                  ),
                ),
              ],
            ),
          ),
        ));
  }
}
